
#ifndef _SerialPort_H_
#define _SerialPort_H_

/*

DM&P Serial Port Library
Copyright (C) 2008 by DM&P.

This library is for DM&P product user only.

*/

enum Baud_t
{
  BAUD_50     = 0x900,
  BAUD_75     = 0x600,
  BAUD_110    = 0x417,
  BAUD_300    = 0x180,
  BAUD_1200   = 0x60,
  BAUD_2400   = 0x30,
  BAUD_4800   = 0x18,
  BAUD_9600   = 0x0c,
  BAUD_14400  = 0x8,
  BAUD_19200  = 0x6,
  BAUD_38400  = 0x3,
  BAUD_57600  = 0x2,
  BAUD_115200 = 0x1
};

enum Parity_t
{
  PARITY_NO   = 0x00,
  PARITY_ODD  = 0x08,
  PARITY_EVEN = 0x18,
  PARITY_MARK = 0x28,
  PARITY_Space= 0x38
};

enum Length_t
{
  LENGTH_5_BIT= 0,
  LENGTH_6_BIT= 1,
  LENGTH_7_BIT= 2,
  LENGTH_8_BIT= 3
};

enum StopBit_t
{
  STOPBIT_1_BIT = 0x00,
  STOPBIT_2_BIT = 0x04
};

enum COM_t
{
  COM1          = 0x00,
  COM2          = 0x01,
  COM3          = 0x02,
  COM4          = 0x03,
  COM5          = 0x04,
  COM6          = 0x05,
  COM7          = 0x06,
  COM8          = 0x07,
};

#ifdef __cplusplus
extern "C" {
#endif

char *SerPort_Version();
int   SerPort_Open         (enum COM_t ComPort,unsigned int nBufSize,unsigned int nBaseAddr,unsigned int nIrq);
int   SerPort_Close        (enum COM_t ComPort);
int   SerPort_IsOk         (enum COM_t ComPort);
void  SerPort_SetParam     (enum COM_t ComPort,enum Baud_t Baud,enum Parity_t Parity,enum Length_t Length,enum StopBit_t StopBit);
void  SerPort_Clear        (enum COM_t ComPort);
int   SerPort_IsParityError(enum COM_t ComPort);
int   SerPort_GetDTR       (enum COM_t ComPort);
void  SerPort_SetDTR       (enum COM_t ComPort,int n);
int   SerPort_GetRTS       (enum COM_t ComPort);
void  SerPort_SetRTS       (enum COM_t ComPort,int n);
unsigned int SerPort_Avail(enum COM_t ComPort);

int  SerPort_SendBuf (enum COM_t ComPort,const char *pcBuf,unsigned int nSize);
int  SerPort_SendStr (enum COM_t ComPort,const char *szStr);
int  SerPort_SendByte(enum COM_t ComPort,char c);
int  SerPort_RecvBuf (enum COM_t ComPort,char *pcBuf,unsigned int nSize);
int  SerPort_RecvByte(enum COM_t ComPort,char *pc);

#ifdef __cplusplus
}
#endif

#endif /* _SerialPort_H_ */
